==> haskell-alsa-mixer-0.3.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-mixer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-mixer
version:              0.3.0
visibility:           public
id:                   alsa-mixer-0.3.0-Df0VQbxglXOHshtZWJp76m
key:                  alsa-mixer-0.3.0-Df0VQbxglXOHshtZWJp76m
license:              BSD-3-Clause
copyright:            2014-2018 Thomas Tuegel
maintainer:           Thomas Tuegel <ttuegel@mailbox.org>
author:               Thomas Tuegel <ttuegel@mailbox.org>
homepage:             https://github.com/ttuegel/alsa-mixer
synopsis:             Bindings to the ALSA simple mixer API.
description:
    This package provides bindings to the ALSA simple mixer API.

category:             Sound
abi:                  3f25e4ee4dd5fb9016f4c34f62b3a25b
exposed:              True
exposed-modules:      Sound.ALSA.Mixer
hidden-modules:       Sound.ALSA.Mixer.Internal
import-dirs:          /usr/lib/ghc-8.10.4/site-local/alsa-mixer-0.3.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/alsa-mixer-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/alsa-mixer-0.3.0
hs-libraries:         HSalsa-mixer-0.3.0-Df0VQbxglXOHshtZWJp76m
extra-libraries:      asound
depends:
    alsa-core-0.5.0.1-JKR0FvUyCWbAEsD75IcPTP base-4.14.1.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-alsa-mixer/html/alsa-mixer.haddock
haddock-html:         /usr/share/doc/haskell-alsa-mixer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-alsa-mixer-0.3.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-alsa-mixer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 alsa-mixer
version:              0.3.0
visibility:           public
id:                   alsa-mixer-0.3.0-5HURTTVUaoZ47a0GxIGkNx
key:                  alsa-mixer-0.3.0-5HURTTVUaoZ47a0GxIGkNx
license:              BSD-3-Clause
copyright:            2014-2018 Thomas Tuegel
maintainer:           Thomas Tuegel <ttuegel@mailbox.org>
author:               Thomas Tuegel <ttuegel@mailbox.org>
homepage:             https://github.com/ttuegel/alsa-mixer
synopsis:             Bindings to the ALSA simple mixer API.
description:
    This package provides bindings to the ALSA simple mixer API.

category:             Sound
abi:                  883ab513abe1baf3102f27640fa8724b
exposed:              True
exposed-modules:      Sound.ALSA.Mixer
hidden-modules:       Sound.ALSA.Mixer.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/alsa-mixer-0.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/alsa-mixer-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/alsa-mixer-0.3.0
hs-libraries:         HSalsa-mixer-0.3.0-5HURTTVUaoZ47a0GxIGkNx
extra-libraries:      asound
depends:
    alsa-core-0.5.0.1-21ZABdX9DCCCoc3hXQrDOJ base-4.14.2.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-alsa-mixer/html/alsa-mixer.haddock
haddock-html:         /usr/share/doc/haskell-alsa-mixer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
